% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/procotWKS.R
\name{procotWKS}
\alias{procotWKS}
\title{Weighted Orthogonal Procrustes Rotation
by Koschat and Swayne's method}
\usage{
procotWKS(A, C, D2, Tinit = diag(ncol(A)), Aainit = NULL, maxiter = 200,
  eps = 1e-06, epsd = 0.001, SQUAREM = 3, nSQUAREM = 1,
  minalpha = -999, maxalpha = -1, always = 0, reset1 = 0, reset2 = 1,
  print = 1)
}
\arguments{
\item{A}{The matrix to be rotated}

\item{C}{The target matrix}

\item{D2}{The weight matrix}

\item{Tinit}{initial value of T matrix}

\item{Aainit}{= Aa matrix which stays constant in this function.}

\item{maxiter}{max # of iterations}

\item{eps}{convergence criterion for rmse}

\item{epsd}{convergence criterion for maximum absolute differences.}

\item{SQUAREM}{= 3 :   See the help of iSQUAREM in lazy.accel package.}

\item{nSQUAREM}{= 1 :   See the help of iSQUAREM in lazy.accel package.}

\item{minalpha}{= -999 :   See the help of iSQUAREM in lazy.accel package.}

\item{maxalpha}{= -1 :   See the help of iSQUAREM in lazy.accel package.}

\item{always}{= 1 :   See the help of iSQUAREM in lazy.accel package.}

\item{reset1}{= 0 :   See the help of iSQUAREM in lazy.accel package.}

\item{reset2}{= 1 :   See the help of iSQUAREM in lazy.accel package.}

\item{print}{= 1 to print the result}
}
\value{
A list of B=A T, T, Cm, A, C, D2, rmse, rmse0 \cr
where B is the rotated matrix, T is the rotation matrix, \cr
Cm is the target matrix with its missing elements replaced by LSE, \cr
rmse and rmse0 are, resp, weighted and unweighted RMSE.
}
\description{
Weighted Orthogonal Procrustes Rotation
by Koschat and Swayne's method
}
\details{
This program minimizes \cr
   RSS = Tr( ( C  - A T ) D2 ( C - A T )' ) \cr
 w.r.t T subject to T'T = TT' = I, \cr
using  Koschat and Swayne (1991) algorithm. \cr
The missing elements of C matrix will be estimated so that they also
minimize RSS.
}
\examples{
seed <- 1701; set.seed(seed)
nvar <- 20; ndim <- 4
errstd <- 0.1
resg <- gendataWmm( 1, nvar, ndim )
A <- resg$A; Cg <- resg$C; Tg <- resg$T
C <- resg$C + errstd*matrix(rnorm(nvar*ndim),nvar)
pmiss <- 0.5
locmiss <- unique( sample(1:(nvar*ndim), pmiss*(nvar*ndim), replace=1) )
C[locmiss] <- NA
V <- diag(ndim)
V <- matrix(rnorm(nvar*ndim),nvar); V <- t(V)\%*\%V/nvar
Print(A,C,V)
res <- procotWKS( A, C, V )

}
\references{
Koschat, M.A., and Swayne, D.F., (1989). A weighted Procrustes criterion.
Psychometrika, 56(2), pp. 229-239.
}
