% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/procotWeW.R
\name{procotWeW}
\alias{procotWeW}
\title{Weighted Expanded Orthogonal Procrustes Rotation \cr
The Ultimate Model}
\usage{
procotWeW(A, C, V, estm = 0, estT = 1, estW = 0, estW2 = 0, W = NULL,
  T = NULL, m = NULL, W2 = NULL, maxiter = 200, eps = 1e-06,
  maxiter2 = 20, eps2 = 1e-06, print = 2)
}
\arguments{
\item{A}{The input matrix to be rotated}

\item{C}{The target matrix}

\item{V}{The weight matrix (known)}

\item{estm}{= 1 to estimate m}

\item{estT}{= 0 to avoid estimation of T}

\item{estW}{= 1 to estimate scalar W \cr
= 2 to estimate diagonal W matrix}

\item{estW2}{= 1 to estimate diagonal W2 matrix}

\item{W}{Initial value of W or NULL}

\item{T}{Initial value of T or NULL}

\item{m}{Initial value of m or NULL}

\item{W2}{Initial value of W2 or NULL}

\item{maxiter}{max # of iterations}

\item{eps}{convergence criterion for rmse}

\item{maxiter2}{max # of iterations for procotWKS}

\item{eps2}{convergence criterion for procotWKS}

\item{print}{= 1 to print result}
}
\value{
A list of: \cr
B=A \%*\% W \%*\% T + matrix(1,nv,1)\%*\%t(m), T, m, W, W2
, Cm the updated target matrix, rmse=sqrt(RSS)
}
\description{
Weighted Expanded Orthogonal Procrustes Rotation \cr
The Ultimate Model
}
\details{
This program finds those A, m, W, W2  and orthonormal T which minimize \cr
  RSS = tr( ( C  - Chat )  V ( C - Chat )' ) \cr
  where Chat = A \%*\% W \%*\% T \%*\% W2 + matrix(1,nv) \%*\% t(m),
  W  and W2 are diagonal matrices, T is an orthonormal rotation matrix, \cr
  m is the column mean vector. \cr
\cr
Note that when estW=0, estW2=0 and estm=0, and the target matrix does not
have missing elements, \cr
this is equivalent to the usual orthogonal Procrustes rotation.
}
\examples{
 seed <- 1701; n <- 20; nr <- 2; pmiss <- 0; errstd <- 0.05
 set.seed(seed)
 resg <- gendataWmm( 1, n, nr, genm=1, genW=2, genW2=1, genV=1
                   , pmiss=pmiss, errstd=errstd )
 A <- resg$A; V <- resg$V
 C <- resg$C; Tg <- resg$T; mg <- resg$m; Wg <- resg$W; W2g <- resg$W2
 res <- procotWeW( A, C, V, estm=1, estW=2, estW2=1, print=1 )
 T <- res$T; m <- res$m; W <- res$W; W2 <- res$W2
 Print( Tg-T, mg-m, fmt="7.3" )
 Print( Wg-W, W2g-W2, fmt="7.3" )

}
