% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/procote.R
\name{procote}
\alias{procote}
\title{Extened Orthogonal Procrustes Rotation}
\usage{
procote(A, C, estm = 0, estd = 0, maxiter = 200, eps = 1e-06,
  print = 2)
}
\arguments{
\item{A}{The input matrix to be rotated}

\item{C}{The target matrix}

\item{estm}{= 1 to estimate column means}

\item{estd}{= 1 to estimate scaling constant}

\item{maxiter}{max # of iterations}

\item{eps}{convergence criterion for rmse}

\item{print}{= 0 to surpress the output}
}
\value{
A list of: \cr
B=d * A \%*\% T + matrix(1,nv,1)\%*\%t(m), \cr
 T, m, d, Cm the updated target matrix, rmse=sqrt(RSS)
}
\description{
Extened Orthogonal Procrustes Rotation
}
\details{
This program finds those A, m, d  and orthonormal T which minimize \cr
  RSS = tr( ( C  - Chat )' ( C - Chat ) ) \cr
  where Chat = d * A \%*\% T + matrix(1,nv) \%*\% t(m),
  d is a scalar, T is an orthonormal rotation matrix, \cr
  m is the column mean vector. \cr
\cr
Note that when estd=0 and estm=0, and the target matrix does not
have missing elements, \cr
this is equivalent to the usual orthogonal Procrustes rotation.
}
\examples{
 seed <- 1701; n <- 20; r <- 4; pmiss <- 0; errstd <- 0.05
 set.seed(seed)
 resg <- gendataWmm( 1, n, r, 1, 1, pmiss=pmiss, errstd=errstd )
 A <- resg$A
 C <- resg$C; Tg <- resg$T; mg <- resg$m; dg <- resg$W[1]
 res <- procote( A, C, estm=1, estd=1, print=1 )
 T <- res$T; m <- res$m; d <- res$d
 Print(Tg-T,mg-m,dg-d, fmt="7.3")

}
