% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/procoteW.R
\name{procoteW}
\alias{procoteW}
\title{Expanded Orthogonal Procrustes Rotation}
\usage{
procoteW(A, C, estm = 0, estW = 0, minW = 0.001, T = NULL, W = NULL,
  m = NULL, maxiter = 200, eps = 1e-06, print = 2)
}
\arguments{
\item{A}{The input matrix to be rotated}

\item{C}{The target matrix}

\item{estm}{= 1 to estimate m}

\item{estW}{= 1 to estimate scalar W \cr
= 2 to estimate diagonal W}

\item{minW}{minimum value of the elements of W}

\item{T}{Initial value of T or NULL}

\item{W}{Initial value of W or NULL}

\item{m}{Initial value of m or NULL}

\item{maxiter}{max # of iterations}

\item{eps}{convergence criterion for rmse}

\item{print}{= 1 to print result}
}
\value{
A list of: \cr
B=A \%*\% W \%*\% T + matrix(1,nv,1)\%*\%t(m), T, W,
, C the updated target matrix, rmse=sqrt(RSS)
}
\description{
Expanded Orthogonal Procrustes Rotation
}
\details{
This program finds those A, m, W  and orthonormal T which minimize \cr
  RSS = tr( ( C  - Chat )' ( C - Chat ) ) \cr
  where Chat = A \%*\% W \%*\% T + matrix(1,nv) \%*\% t(m),
  W is a diagonal Matrix, T is an orthonormal rotation matrix, \cr
  m is the column mean vector. \cr
\cr
Note that when estW=0 and estm=0, and the target matrix does not
have missing elements, \cr
this is equivalent to the usual orthogonal Procrustes rotation.
}
\examples{
 seed <- 1701; n <- 20; nr <- 2; pmiss <- 0; errstd <- 0.05
 set.seed(seed)
 resg <- gendataWmm( 1, n, nr, genm=1, genW=2, pmiss=pmiss, errstd=errstd)
 A <- resg$A
 C <- resg$C; Tg <- resg$T; mg <- resg$m; Wg <- resg$W
 res <- procoteW( A, C, estm=1, estW=2, print=1 )
 T <- res$T; m <- res$m; W <- res$W
 Print( Tg-T, mg-m, Wg-W, fmt="7.3")


}
