% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/procrustes.R
\name{procrustes}
\alias{procrustes}
\title{Procrustes Rotation with Prescribed Factor Correlations}
\usage{
procrustes(A, C, Phia = diag(ncol(A)), Phib = NULL, Tinit = NULL,
  maxiter = 500, eps = 1e-06, epsd = 1e-06, maxiter2 = 200,
  eps2 = 1e-06, epsd2 = 0.001, SQUAREM = 3, nSQUAREM = 1,
  minalpha = -999, maxalpha = -1, always = 0, reset1 = 0, reset2 = 1,
  print = 1)
}
\arguments{
\item{A}{The matrix to be rotated}

\item{C}{The target matrix}

\item{Phia}{The factor correlation matrix associated with A}

\item{Phib}{The factor correlation of the rotated factors}

\item{Tinit}{initial value of T matrix}

\item{maxiter}{max # of iterations}

\item{eps}{convergence criterion for rmse}

\item{epsd}{convergence criterion for maximum absolute differences of Q.}

\item{maxiter2}{max # of iterations of procotWKS}

\item{eps2}{convergence criterion for rmse of procotWKS}

\item{epsd2}{convergence criterion for maximum absolute differences
of procotWKS}

\item{SQUAREM}{= 3 :   See the help of iSQUAREM in lazy.accel package.}

\item{nSQUAREM}{= 1 :   See the help of iSQUAREM in lazy.accel package.}

\item{minalpha}{= -999 :   See the help of iSQUAREM in lazy.accel package.}

\item{maxalpha}{= -1 :   See the help of iSQUAREM in lazy.accel package.}

\item{always}{= 1 :   See the help of iSQUAREM in lazy.accel package.}

\item{reset1}{= 0 :   See the help of iSQUAREM in lazy.accel package.}

\item{reset2}{= 1 :   See the help of iSQUAREM in lazy.accel package.}

\item{print}{= 1 to print the result}
}
\value{
A list of  B, T, Q, Cm, A, C, Phia, Phib, rmse, \cr
where B is the rotated matrix, T is the rotation matrix, \cr
Q is the orthogonal matrix which defines T, and \cr
Cm is the target matrix with its missing elements replaced by LSE.
}
\description{
Procrustes Rotation with Prescribed Factor Correlations
}
\details{
This function finds the factor rotation matrix T of the form: \cr
   g=T'f and B=A inv(T') \cr
 which minimizes the least squares criterion: \cr
  RSS = tr(  (C - B)'(C - B) ) \cr
 subject to corr(g)=Phib. \cr
 The rotation matrix T can be defined as: \cr
    where T = P inv(K) Q D R'  and  QQ'=Q'Q=I, \cr
    where corr(f)=Phia=P K2 P'  and  corr(g)=Phib=R D2 R'. \cr
 The missing elements of C matrix will be estimated so that they also
minimize RSS.
}
\examples{

# Independent Cluster
seed <- 1701
set.seed(seed)

nvar <- 20
ndim0 <- 3
ps <- 0.1
df <- 500
phi <- 0.3
big=0.8

Lambda0 <- gendatafa_A( nvar, ndim0, large=big,small=1-big
                  , pc=0, sd=0 )$loadings
colnames(Lambda0) <- paste("f",1:ndim0,sep="")

Phi <- (1-phi)*diag(ndim0)+phi*matrix(1,ndim0,ndim0)
Sigma <- Lambda0\%*\%Phi\%*\%t(Lambda0)+ps*diag(nvar)
dS <- sqrt(diag(Sigma))
Sigma <- diag(1/dS)\%*\%Sigma\%*\%diag(1/dS)

S <- rWishart( 1, df, Sigma )
S <- S[,,1]/df
dS <- sqrt(diag(S))
S <- diag(1/dS)\%*\%S\%*\%diag(1/dS)

ndim <- ndim0


temp <- lazy.fa::fa_hs( S, ndim=ndim, c="smc" )
Lambda <- temp$Lambda
psi <- temp$psic


Lambda00 <- Lambda0
Lambda00[Lambda00==big] <- 1
Lambda00[Lambda00==1-big] <- 0
Lambda000=Lambda00
Lambda000[Lambda00==1]=NA

phia <- 0; Phia <- (1-phia)*diag(ndim)+phia*matrix(1,ndim,ndim)
table <- NULL
for( p in seq(-0.45, 0.45, 0.05) ){
 Print(p)
 Phib <- (1-p)*diag(ndim)+p*matrix(1,ndim,ndim)
 res <- procrustes( Lambda, Lambda0, Phia=Phia, Phib, print=1, maxiter2=500 )
 table <- rbind(table,c(p,res$rmse))
 Print(res$B)
}
best=table[,2]==min(table[,2])
Print(table,best)

}
